@@ -1,16 +1,16 @@
 /*
  * Test suite for no-op messages in the server.
  *
- * Written by Russ Allbery <rra@stanford.edu>
- * Copyright 2011, 2012
+ * Written by Russ Allbery <eagle@eyrie.org>
+ * Copyright 2011-2013
  *     The Board of Trustees of the Leland Stanford Junior University
  *
- * See LICENSE for licensing terms.
+ * SPDX-License-Identifier: MIT
  */
 
 #include <config.h>
-#include <portable/system.h>
 #include <portable/gssapi.h>
+#include <portable/system.h>
 
 #include <client/internal.h>
 #include <client/remctl.h>
@@ -21,7 +21,7 @@
 #include <util/protocol.h>
 
 /* The no-op token. */
-static const char token[] = { 3, 7 };
+static const char token[] = {3, 7};
 
 
 int
@@ -42,6 +42,8 @@ main(void)
     /* Open the connection to the site. */
     r = remctl_new();
     ok(r != NULL, "remctl_new");
+    if (r == NULL)
+        bail("remctl_new returned NULL");
     ok(remctl_open(r, "localhost", 14373, config->principal), "remctl_open");
 
     /* Send the no-op token. */
